@@ -186,8 +186,14 @@ def parser():
                         people_links = parser_people_links(direct_link)
                         i=4
                     except:
-                        if i == 2 and (direct_link.find('perm') == -1 or direct_link.find('orenburg') == -1):
-                            return [{'code': 1, 'script': os.path.basename(__file__)}]
+                        if i == 2:
+                            if direct_link.find('perm') != -1 :
+                                pass
+                            elif direct_link.find('orenburg') != -1:
+                                pass
+                            else:
+                                return [{'code': 1, 'script': os.path.basename(__file__)}]
+
                         people_links = None
                         i+=1
                         log.warning(f'Duplicate or non-templated html at -> {direct_link}')
@@ -210,3 +216,6 @@ def parser():
         return people
     else:
         return [{'code': 2, 'script': os.path.basename(__file__)}]
+
+if __name__ == '__main__':
+    print(parser())
\ No newline at end of file
